@@ -1,4 +1,4 @@
-ROTcovQUAKE<-function(XQ, proj, sel=1, domap=TRUE, cosomap=NA)
+ROTcovQUAKE<-function(XQ, proj, sel=1, domap=TRUE, cosomap=NA, add=FALSE)
   {
 
     if(missing(sel)) sel = 1:length(XQ)
@@ -21,7 +21,7 @@ ROTcovQUAKE<-function(XQ, proj, sel=1, domap=TRUE, cosomap=NA)
            }
 
     
-    ZEXY = GLOB.XY(ZEDS[,1], ZEDS[,2], proj)
+    ZEXY = GEOmap::GLOB.XY(ZEDS[,1], ZEDS[,2], proj)
     
     for(i in 1:NEQ)
       {
@@ -54,10 +54,13 @@ ROTcovQUAKE<-function(XQ, proj, sel=1, domap=TRUE, cosomap=NA)
       }
     
 
+if(add==FALSE)
+  {
+     rgl::rgl.open()
+    rgl::par3d(windowRect=c(0, 0, 600, 600) )
+   }
 
-     rgl.open()
-    
-  rgl.ellipsoids(POSq, SIZq
+ cda::rgl.ellipsoids(POSq, SIZq
                        , ANGq, col="gold")
 
     
