@@ -1,10 +1,20 @@
-plotJACKLLZ<-function(hjack, sta, proj=NULL, PLOT=0, PS=FALSE )
+plotJACKLLZ<-function(hjack, sta, proj=NULL, PLOT=0, PS=FALSE, fbase="jack", width = c(10, 5), height = c(8,8)  )
 {
-
+###  there are 2 possible plot created eath with a different default size
 
   ###  if plot = {0,1,2}
 #######  plot the output of HiJACK
+  JPNG<-function(file="tmp", width = 8, height = 8)
+    {
+      
+      png(filename = file,
+          width = width, height = height, units='in', pointsize = 12, res=300)
+    }
 
+  if(length(width)<2) { width = c(width[1], 0.5*width[1]) }
+  if(length(height)<2) { height = c(height[1], height[1]) }
+
+  
   YEYE=hjack$Y
   XEYE=hjack$X
   ZEYE=hjack$Z
@@ -54,33 +64,63 @@ Blat = boxplot(YEYEB, plot=FALSE)
  
   Bz = boxplot(ZEYEB, plot=FALSE)
 
+  if(PS==FALSE)
+    {
+  fn1=NA
+  fn2=NA
+}
  ##
   if( PLOT==0 | PLOT==1)
     {
-       op <- par(no.readonly = TRUE) 
-  if(PS==FALSE) dev.new(width=10, height=8)
+      
+      if(PS==TRUE)
+        {
+          fn1=paste(fbase,"1.png", sep="" )
+          JPNG(file=fn1, width=width[1], height=height[1] )
+        }
+      else
+        {
+          op <- par(no.readonly = TRUE) 
+          dev.new(width=width[1], height=height[1])
+        }
 
-  
-  par(mfrow=c(3,1))
+      
+      par(mfrow=c(3,1))
 
-  
-  bxp(Blat, varwidth=TRUE)
-  title("Station Influence Lat")
+      
+      bxp(Blat, varwidth=TRUE)
+      title("Station Influence Lat")
 
-  bxp(Blon, varwidth=TRUE)
-  title("Station Influence Lon")
+      bxp(Blon, varwidth=TRUE)
+      title("Station Influence Lon")
 
-  bxp(Bz, varwidth=TRUE)
-  title("Station Influence Z")
-par(op)
-}
+      bxp(Bz, varwidth=TRUE)
+      title("Station Influence Z")
+      if(PS==TRUE) { dev.off() }
+      else
+        {
+          par(op)
+        }
+    }
 
 
   if( PLOT==0 | PLOT==2)
     {
-  if(PS==FALSE)  dev.new(width=5, height=8)
 
- op <- par(no.readonly = TRUE) 
+      if(PS==TRUE)
+        {
+          fn2=paste(fbase,"2.png", sep="" )
+          JPNG(file=fn2, width=width[2], height=height[2] )
+        }
+      else
+        {
+          dev.new(width=width[2], height=height[2])
+          op <- par(no.readonly = TRUE) 
+        }
+
+
+
+
   par(mfrow=c(3,1))
      
 
@@ -97,8 +137,13 @@ par(op)
   imageINFLUENCE(Bz, sta, proj)
   title("Station Influence Depth")
 
-  par(op)
 
-}
-  return(list( X=XEYEB, Y=YEYEB, Z=ZEYEB) )
+      if(PS==TRUE) { dev.off()}
+      else
+        {
+          par(op)
+        }
+      
+    }
+  return(list( X=XEYEB, Y=YEYEB, Z=ZEYEB, files=c(fn1, fn2)  ) )
 }
